<?php
//#################################################################################################
//	Backendpage class
//#################################################################################################
//	chillyCMS - Content Management System
//	Copyright (C) 2008
//	Stefanie Wiegand <wiegand.stefanie@gmail.com> & Johannes Cox <johannes.cox@gmail.com>
//	
//	This program is licensed under the GPL 3.0 license. For more information see LICENSE.txt.
//#################################################################################################

require_once("page.class.php");

class Backendpage extends Page {
	//special variables
	private $login;
	private $menu;
	private $popup;

	function __construct($login = false, $popup = false) {
		global $settings,$mysession,$is_admin;
		parent::__construct();
		
		//title
		$this->title = "<title>chillyCMS Backend</title>\n";

		//metatags
		$this->meta .= "\t<meta name=\"author\" content=\"Stefanie Wiegand &amp; Johannes Cox\" />\n".
		"\t<meta name=\"keywords\" content=\"chillyCMS, FrozenPepper, Content Management System\" />\n".
		"\t<meta name=\"description\" content=\"chillyCMS Backend\" />\n".
		"\t<meta name=\"robots\" content=\"noindex,nofollow\" />\n".
		"\t<link rel=\"icon\" href=\"../style/images/favicon.ico\" type=\"image/vnd.microsoft.icon\"/>\n";
		
		//stylesheets
		$this->stylesheets = "\t<link rel='stylesheet' href='http://".URL.
		"/style/css/backend.css' type='text/css' />\n".
		"\t<link rel='stylesheet' href='http://".URL.
		"/style/css/".$settings["backendstyle"].".css' type='text/css' />\n";
		
		//scripts
		$this->scripts = "";
		
		//is it a backend login?
		$this->login = $login;
		
		//is it a popup (without menu)?
		$this->popup = $popup;
		
		//menu
		$this->menu = "";
		if ($this->popup == false && $this->login == false) {
			$this->make_menu();
		}
		
		//queries for session backend include = 3
		$this->num_queries = 3;
	}
	//Destructor
	function __destruct() {
		parent::__destruct();
		//$this->login = $this->$menu = false;
	}
	//Getter
	public function __get($name) {
		if (isset($name, $this->$name)) { return $this->$name; }
		else { return false; }	
	}
	
	//generate backend menu
	private function make_menu() {
		global $l_menu,$mysession,$is_admin;
		$gids = $mysession->user->gids;
		
		//what is the active site?	TODO
		$activebackendsite=substr($_SERVER["SCRIPT_FILENAME"],strlen(PATH."/core/"));
		$activebackendsite=substr($activebackendsite,0,-9);

		$this->menu = "<div class='adminmenu'>\n".
		"\t<div class='adminmenu_left'></div>\n".
		"\t<div class='adminmenu_middle'>\n".
		"\t<ul>\n";
		//settings
		if ($is_admin) {
			$this->menu .= "\t\t<li>";
			if ($activebackendsite=="settings") { $this->menu .= "<div class='active'>"; }
			$this->menu .= "<a class='menu_settings' href='../admin/settings.site.php'>$l_menu[lbl_settings]</a>";
			if ($activebackendsite=="settings") { $this->menu .= "</div>"; }
			$this->menu .= "</li>\n";
		}
		//content
		$this->menu .= "\t\t<li>";
		if ($activebackendsite=="content" or $activebackendsite=="edit") { $this->menu .= "<div class='active'>"; }
		$this->menu .= "<a class='menu_content' href='../admin/content.site.php'>$l_menu[lbl_content]</a>";
		if ($activebackendsite=="content" or $activebackendsite=="edit") { $this->menu .= "</div>"; }
		//media
		$this->menu .= "</li>\n\t\t<li>";
		if ($activebackendsite=="media") { $this->menu .= "<div class='active'>"; }
		$this->menu .= "<a class='menu_media' href='../admin/media.site.php'>$l_menu[lbl_media]</a>";
		if ($activebackendsite=="media") { $this->menu .= "</div>"; }
		$this->menu .= "</li>\n";
		//modules
		if ($is_admin) {
			$this->menu .= "\t\t<li>";
			if ($activebackendsite=="modules" or $activebackendsite=="moduleinfo" or $activebackendsite=="modulesedit")
			{ $this->menu .= "<div class='active'>"; }
			$this->menu .= "<a class='menu_modules' href='../admin/modules.site.php'>$l_menu[lbl_modules]</a>";
			if ($activebackendsite=="modules" or $activebackendsite=="moduleinfo" or $activebackendsite=="modulesedit")
			{ $this->menu .= "</div>"; }
			$this->menu .= "</li>\n";
		}
		//design
		if ($is_admin) {
			$this->menu .= "\t\t<li>";
			if ($activebackendsite=="design") { $this->menu .= "<div class='active'>"; }
			$this->menu .= "<a class='menu_design' href='../admin/design.site.php'>$l_menu[lbl_design]</a>";
			if ($activebackendsite=="design") { $this->menu .= "</div>"; }
			$this->menu .= "</li>\n";
		}
		//users/groups
		$this->menu .= "\t\t<li>";
		if ($activebackendsite=="usersgroups" or $activebackendsite=="userform" or $activebackendsite=="groupform") {
			$this->menu .= "<div class='active'>";
		}
		$this->menu .= "<a class='menu_usersgroups' href='../admin/usersgroups.site.php'>$l_menu[lbl_usersgroups]</a>";
		if ($activebackendsite=="usersgroups" or $activebackendsite=="userform" or $activebackendsite=="groupform") {
			$this->menu .= "</div>";
		}
		//tools
		$this->menu .= "</li>\n\t\t<li>";
		if ($activebackendsite=="tools") { $this->menu .= "<div class='active'>"; }
		$this->menu .= "<a class='menu_tools' href='../admin/tools.site.php'>$l_menu[lbl_tools]</a>";
		if ($activebackendsite=="tools") { $this->menu .= "</div>"; }

		$this->menu .= "</li>\n\t\t<li class='menu_small'><a class='menu_logout' href='../admin/login.site.php?".
		"action=logout&amp;reason=logout'>$l_menu[lbl_logout]</a></li>\n".
		"\t\t<li class='menu_small'><a class='menu_preview' href='../core/show.site.php' ".
		"target='_blank'>$l_menu[lbl_preview]</a></li>\n".
		"\t</ul>\n".
		"\t</div>\n".
		"\t<div class='adminmenu_right'></div>\n".
		"</div>\n";
	}	
	
	//use certain scripts
	public function use_scripts($scripts) {
		if (is_array($scripts)) {
			foreach ($scripts as $script) {
				if ($script=="ckeditor") {
					$this->scripts = "\t<script type='text/javascript' src='../scripts/specialrightsmenu.js'></script>\n".
					"\t<script type='text/javascript' src='../modules/ckeditor/ckeditor.js'></script>\n";
				} else {
					$this->scripts .= "\t<script type='text/javascript' src='../scripts/$script'></script>\n";
				}
			}
		} elseif ($scripts=="ckeditor") {
			$this->scripts = "\t<script type='text/javascript' src='../scripts/specialrightsmenu.js'></script>\n".
			"\t<script type='text/javascript' src='../modules/ckeditor/ckeditor.js'></script>\n";
		} else {
			$this->scripts = "\t<script type='text/javascript' src='../scripts/$scripts'></script>\n";
		}
	}
	//print functions
	public function print_head() {
		echo $this->doctype.
		"<head>\n".
		$this->title.
		$this->meta.
		$this->stylesheets.
		$this->scripts.
		"</head>\n";
	}
	public function print_body($msg) {
		global $settings;
		echo "<body>\n";
		
		//debug mode?
		if (intval($settings["debug_mode"])==1) {
			$this->stop_time	= microtime(true);
			$this->load_time = round(($this->stop_time - $this->start_time),6)*1000;
			ini_set('display_errors',1);
			error_reporting(E_ALL);
			echo "\t<div class='debug'>\n".
			"\t\t<p><strong>::: <em>chillyCMS</em> Debug Mode :::</strong></p>\n".
			"\t\t<p>This page was generated in <strong>$this->load_time</strong> ms.</p>\n".
			"\t\t<p>It took <strong>$this->num_queries</strong> queries.</p>\n".
			"\t</div>\n";
		}

		if ($this->popup == false) {
			//backend wrapper
			echo "<div class='wrapper'>\n".
			//mainmenu
			$this->menu.
			"<div class='mainbackend'>\n".
			//message
			"\t<div class='wrapper_top'>\n".
			"\t\t<div class='wrapper_top_left'></div>\n".
			"\t\t<div class='wrapper_top_middle'>\n";
			if (is_array($msg) && sizeof($msg)==2) {
				$mymsg=escape_html($msg[0]);
				$type=escape_html($msg[1]);
				echo "\t\t\t<div class='message'>\n";
				if ($type && $type!="" && $mymsg!="") {
					echo "\t\t\t\t<div class='message_left_".$type."'></div>\n";
					echo "\t\t\t\t<p class='$type'>$mymsg</p>\n";
					echo "\t\t\t\t<div class='message_right_".$type."'></div>\n";
				}
				echo "\t\t\t</div>\n";
			}
			echo "\t\t</div>\n".
			"\t\t<div class='wrapper_top_right'></div>\n".
			"\t</div>\n".
			"\t<div class='clr'></div>\n".
			"\t<div class='admincontent'>\n".
			"\t</div>\n";
		} else {
			echo "<div class='popup'>\n";
		}
		//content of the backend page
		echo $this->content;
		
		if ($this->popup == false) {
			//sticky footer
			echo "\t<div class='clr backendbottom'></div>\n".
			"\t<div class='push'></div>\n".
			"</div>\n";
		}
		echo "</div>\n";
		
		if ($this->popup == false) {
			//footer
			echo "<div class='footer_full'>\n".
			"\t<div class='footer'>\n".
			"\t\t<div class='footer_inner'>\n".
			"\t\t\t<p class='footerleft'>chillyCMS ";
			if (!$this->login) { echo $settings["version"]." "; }
			echo "&copy;2008 - ".date("Y")." Stefanie Wiegand &amp; Johannes Cox</p>\n";
			if (!$this->login) {
				echo "\t\t\t<p class='footerright'>".
				"<a href='http://".URL."/admin/credits.site.php'>More Credits</a></p>\n";
			}
			echo "\t\t</div>\n".
			"\t\t</div>\n".
			"\t</div>\n";
		}
		echo "</body>\n".
		"</html>\n";
	}
} ?>
