<?php
//#################################################################################################
//	Site class
//#################################################################################################
//	chillyCMS - Content Management System
//	Copyright (C) 2008
//	Stefanie Wiegand <wiegand.stefanie@gmail.com> & Johannes Cox <johannes.cox@gmail.com>
//	
//	This program is licensed under the GPL 3.0 license. For more information see LICENSE.txt.
//#################################################################################################

require_once("database.class.php");
require_once("helpers.include.php");
require_once("listitem.class.php");
require_once("webuser.class.php");

$allpos = array("top","left","right","bottom","user0","user1","user2","user3",
"user4","user5","user6","user7","user8","user9");

class Site {
//Class variables//////////////////////////////////////////////////////////////////////////
private $language;			//active language
private $pagetitle;
private $author;
private $siteemail;
private $backendstyle;
private $template;			//active template
private $keywords;
private $description;
private $dofirst;			//a file to be executed before anything else
private $headlinks;			//something that is to be included in the html head

private $positions;			//all positions with the submodules they contain
private $id;				//the id to show
private $name;				//the name to show
private $mainmodname;			//the name of the mainmodule that is to be displayed
private $settings;			//the settings to show
private $access;			//the access to show
private $specialaccess;			//the specialaccess to show
private $content;			//the content to show
private $submodules;			//all modules on that site
private $stylesheets;			//the stylesheets of the modules used in the site
private $countme;			//count the visit of the pagecall?
//Functions////////////////////////////////////////////////////////////////////////////////
//Constructor
function __construct() {
	global $allpos,$settings;
	
	//Get settings from database
	$this->language = $settings["language"];
	$this->pagetitle = $settings["sitename"];
	$this->author = $settings["author"];
	$this->siteemail = $settings["siteemail"];
	$this->backendstyle = $settings["backendstyle"];
	$this->template = $settings["template"];
	$this->keywords = $settings["keywords"];
	$this->description = $settings["description"];
	
	//Count site visits
	$this->countme=false;
	$cookievalue=num_text($this->pagetitle);
	$visited=false;
	if (is_array($_COOKIE["chillyCMS"])) {
		foreach ($_COOKIE["chillyCMS"] as $cookie=>$value) {
			if ($cookie==$cookievalue && $value=="visited") {
				$visited=true;
				break;
			}
		}
	}
	if (!$visited) {
		if (!headers_sent()) { setcookie("chillyCMS[$cookievalue]","visited"); }
		$this->countme=true;
	}
	$this->increment_stats();
	
	//Get all positions from template file
	require_once(PATH."/templates/".$this->template."/config.php");
	$this->positions=$positions;
	$db = new Database();
	$request=escape($_REQUEST);
	if (isset($request["id"])) {
		$this->id = intval($_REQUEST["id"]);
		$db->query("select c.*, m.name as modname from site_content as c, system_modules as m ".
		"where c.modid=m.modid and c.id=$this->id limit 1");
		$result = $db->getdata();
	} else {
		$this->id = 0;
		$db->query("select c.*, m.name as modname from site_content as c, system_modules as m ".
		"where c.modid=m.modid and c.startpage='1' limit 1");
		$result = $db->getdata();
		if (!empty($result)) { $this->id = $result["id"]; }
	}
	//Get all submodules
	$db->query("select m1.*, ifnull(m2.id,0) as prev, ifnull(m3.id,0) as next, ".
	"s.name as modname from site_modules as m1 ".
	"left join site_modules m2 on m2.order=m1.order-1 and m1.position=m2.position ".
	"left join site_modules m3 on m3.order=m1.order+1 and m1.position=m3.position ".
	"left join system_modules s on s.modid=m1.modid ".
	"order by m1.position,m1.order");
	$moddata = $db->getdata_array();
	$db->close();
	$this->name = $result["name"];
	$this->mainmodname = $result["modname"];
	$this->settings = $result["settings"];
	$this->access = $result["access"];
	$this->specialaccess = $result["specialaccess"];
	$this->content = $result["content"];
	//Get all modules inside the positions
	$this->submodules=array();
	$this->stylesheets=array();
	$this->stylesheets["normal"]=array();
	$this->stylesheets["ie6"]=array();
	//Get the stylesheets of the mainmodule if they exist
	if (file_exists(PATH."/modules/$result[modname]/$result[modname].css")) {
		$this->stylesheets["normal"][] = "<link rel='stylesheet' href='../modules/$result[modname]/".
		"$result[modname].css' type='text/css' />\n";
	}
	if (file_exists(PATH."/modules/$result[modname]/ie6.css")) {
		$this->stylesheets["ie6"][]="<link rel='stylesheet' ".
		"href='../modules/$result[modname]/ie6.css' type='text/css' />\n";
	}
	$this->dofirst=array();
	//Get dofirst action from mainmod if exists
	if (file_exists(PATH."/modules/$result[modname]/dofirst.php")) {
		$this->dofirst[]=PATH."/modules/$result[modname]/dofirst.php";
	}
	$this->headlinks=array();
	//Get things that are to be included in the html head
	if (file_exists(PATH."/modules/$result[modname]/headlink.php")) {
		$this->headlinks[]=PATH."/modules/$result[modname]/headlink.php";
	}
	foreach ($this->positions as $thispos) {
		if (in_array($thispos,$allpos)) {
			if (is_array($moddata) && !empty($moddata)) {
				foreach ($moddata as $mod) {
					if ($thispos==$mod["position"]) {
						$this->submodules[$thispos][] = $mod;
						//Get the stylesheets of the submodule if it exists
						if (file_exists(PATH."/modules/$mod[modname]/$mod[modname].css")) {
							$newstylesheet="<link rel='stylesheet' ".
							"href='../modules/$mod[modname]/$mod[modname].css' type='text/css' />";
							if (!in_array($newstylesheet,$this->stylesheets["normal"])) {
								$this->stylesheets["normal"][]=$newstylesheet;
							}
						}
						if (file_exists(PATH."/modules/$mod[modname]/ie6.css")) {
							$newstylesheet="<link rel='stylesheet' ".
							"href='../modules/$mod[modname]/ie6.css' type='text/css' />";
							if (!in_array($newstylesheet,$this->stylesheets["ie6"])) {
								$this->stylesheets["ie6"][]=$newstylesheet;
							}
						}
						//Get dofirst action from submod if exists
						if (file_exists(PATH."/modules/$mod[modname]/dofirst.php")) {
							$dofirst=PATH."/modules/$mod[modname]/dofirst.php";
							if (!in_array($dofirst,$this->dofirst))
							$this->dofirst[]=$dofirst;
						}
						//Get things that are to be included in the html head
						if (file_exists(PATH."/modules/$mod[modname]/headlink.php")) {
							$this->headlinks[]=PATH."/modules/$mod[modname]/headlink.php";
						}
					}
				}
			}
		}
	}
}
//Destructor
function __destruct() {
	$this->language=$this->pagetitle=$this->author=$this->siteemail=$this->backendstyle=$this->template=
	$this->keywords=$this->description=$this->positions=$this->id=$this->name=$this->mainmodname=$this->settings=
	$this->access=$this->specialaccess=$this->content=$this->submodules=$this->stylesheets=$this->countme=false;	
}
//Getter
public function __get($name) {
	if (isset($name, $this->$name)) { return $this->$name; }
	else { return false; }	
}
//Insert Stylesheets and Metatags
function head() {
	global $settings,$title;
	echo "<title>$title</title>";
	//insert module stylesheets
	foreach ($this->stylesheets["normal"] as $css) {
		echo "\n\t$css";
	}
	if (!empty($this->stylesheets["ie6"])) {
		foreach ($this->stylesheets["ie6"] as $css) {
				echo "\n\t<!--[if lte IE 6]>$css<![endif]-->";
		}
	}
	//metatags
	echo "\n\t<meta http-equiv='Content-Type' content='text/html;charset=iso-8859-1' />\n".
	"\t<meta name='robots' content='index,follow' />\n".
	"\t<meta name='revisit-after' content='7 days' />\n".
	"\t<meta name='Content-Language' content='$this->language' />\n".
	"\t<meta name='keywords' content='$settings[keywords]' />\n".
	"\t<meta name='description' content='$settings[description]' />\n".
	//favicon
	"\t<link rel='icon' href='../templates/$this->template/favicon.ico' type='image/vnd.microsoft.icon'/>\n".
	//frontend stylesheet
	"\t<link rel='stylesheet' href='../style/css/frontend.css' type='text/css'/>\n";
	//head links
	if (!empty($this->headlinks)) {
		foreach ($this->headlinks as $hl) {
			echo "\t";
			include($hl);
			echo "\n";
		}
	}
}
//Show module
function show_position($position) {
	global $is_logged,$is_user,$is_admin,$mysession;
	//is it a valid position for the used template?
	if (in_array($position,$this->positions)) {
		//find out what module is in that position
		$sortedmods=array();
		if (is_array($this->submodules[$position]) && !empty($this->submodules[$position])) {
			foreach ($this->submodules[$position] as $row) {
				$sortedmods[]=new Listitem($row["id"],$row["order"],$row["prev"],$row["next"],
				array("name"=>$row["name"],"modname"=>$row["modname"],"active"=>$row["active"],
				"settings"=>$row["settings"],"access"=>$row["access"],
				"specialaccess"=>$row["specialaccess"]));
			}
		}
		//sort modules
		if (!empty($sortedmods)) {
			foreach ($sortedmods as $thismod) {
				$modinstanceid=$thismod->id;
				$modinstancename=$thismod->data["name"];
				$modsettings=$thismod->data["settings"];
				$sitelanguage=$this->language;
				//if it can be accessed for everybody
				if ($thismod->data["active"]=="1") {
					if ($thismod->data["access"]=="0" or ($thismod->data["access"]=="1" && $is_user)
					or ($thismod->data["access"]=="2" && $is_admin)) {
						$modpath=PATH."/modules/".$thismod->data["modname"];
						//load the matching language file if it exists
						if (file_exists($modpath."/languages/$this->language.php")) {
							include($modpath."/languages/$this->language.php");
						//if no, try to load the "en" language file
						} elseif (file_exists($modpath."/languages/en.php")) {
							include($modpath."/languages/en.php");
						}
						//...load that very module
						include($modpath."/config.php");
						include($modpath."/$outputfile");					
					}
				}
			}
		}		
	}
}
//Show Content
function show_content() {
	global $is_logged,$is_user,$is_admin,$mysession,$l_core,$l_gen,$l_log,$timeout,$settings;
	
	$showcontent=true;
	//load the language
	if (isset($_REQUEST["register"]) || isset($_REQUEST["forgotdata"]) || isset($_REQUEST["editprofile"])
	 || isset($_REQUEST["feedbackuser"]) || isset($_REQUEST["goodfeedback"]) || isset($_REQUEST["badfeedback"])) {
		include(PATH."/modules/login/languages/$this->language.php");
	}
	//user wants to register
	if (isset($_REQUEST["register"])) {
		include_once(PATH."/modules/login/register.php");
		$showcontent=false;
	//user has forgotten his name and/or password
	} else if (isset($_REQUEST["forgotdata"])) {
		include_once(PATH."/modules/login/forgotdata.php");
		$showcontent=false;
	//user wants to edit his profile
	} else if (isset($_REQUEST["editprofile"])) {
		if ($is_logged && $is_user) {
			include_once(PATH."/modules/login/editprofile.php");
		}
		$showcontent=false;
	//user was logged out
	} else if ($_REQUEST["action"]=="logout") {
		//--by himself
		if ($_POST["reason"]=="logout") {
			//ask the user whether he liked the website?
			if (isset($_POST["feedbackuser"])) {
				include_once(PATH."/modules/login/satisfactiondemand.php");
				$showcontent=false;
			} else {
				echo $l_log["lbl_logout"];
			}
		//--by inactivity
		} else {
			echo $l_gen["lbl_sorry"].", ".$_GET["user"]."! ".$l_log["msg_timeout1_err"].
			round($settings["session_ltime"]/60,0).$l_log["msg_timeout2_err"]." ".$l_log["msg_sessionend"];
		}
	//the user liked the system
	} else if (isset($_GET["goodfeedback"])) {
		include_once(PATH."/modules/login/goodfeedback.php");
		$showcontent=true;
	//the user didn't like the system and writes something about it
	} else if (isset($_REQUEST["badfeedback"])) {
		include_once(PATH."/modules/login/badfeedback.php");
		if ($_POST["feedback"]=="") { $showcontent=false; }
	}
	if ($showcontent) {
		$specialaccess = explode(",",$this->specialaccess);
		$modsettings = $this->settings;
		//site is not for everybody
		//--users only
		if ($this->access == "1") {
			if (!($is_user or $is_admin)) {
				echo "<b>$l_core[lbl_uonly]</b><br />";
				$showcontent = false;
			}
		//--admins only
		} else if ($this->access == "2") {
			if (!$is_admin) {
				$ok = false;
				$gids=$mysession->user->gids;
				//is there any special access?
				if (!empty($gids)) {
					if (!empty($specialaccess)) {
						foreach ($specialaccess as $spac) {
							if (in_array($spac,$gids)) {
								$ok = true;
								break;
							}
						}
					}
				}
				if (!$ok) {
					echo "<b>$l_core[lbl_aonly]</b><br />";
					$showcontent = false;
				}
			}
		}
		if ($showcontent) {
			//Module found
			if ($this->mainmodname!="") {
				//increment views of the content
				db_query("update site_content set views=views+1 where id=$this->id");
				$modpath=PATH."/modules/$this->mainmodname";
				include_once("$modpath/config.php");
				//load the matching language file if it exists
				if (file_exists($modpath."/languages/$this->language.php")) {
					include_once($modpath."/languages/$this->language.php");
				//if no, try to load the "en" language file
				} elseif (file_exists($modpath."/languages/en.php")) {
					include_once($modpath."/languages/en.php");
				}
				include_once("$modpath/$outputfile");
			} else {	
				include_once(PATH."/core/404.php");
			}
		}
	}
}
function increment_stats () {
	if ($this->countme==true) {
		//collect visitor data for analysis tool
		$wu = new Webuser();
		if (!$wu->isbot) {
			$sql = "select `id`,`month`,`visits`,`browsers`,`oss`,`countries` from site_visitors ".
			"where `id`=(select max(id) from site_visitors limit 1)";
			$result=db_query($sql);
			$browsers = $oss = $countries = array();
			//still the same month?
			$now = date("m/Y",time());
			if ($now == $result["month"]) {
				//read from db:
				//--browsers
				$dbbrowsers = explode(",",$result["browsers"]);
				foreach ($dbbrowsers as $dbbrowser) {
					$browser=explode(":",$dbbrowser);
					if ($dbbrowser[0]!="") { $browsers[$browser[0]]=$browser[1]; }
				}
				//--oss
				$dboss = explode(",",$result["oss"]);
				foreach ($dboss as $dbos) {
					$os = explode(":",$dbos);
					if ($dbos[0]!="") { $oss[$os[0]]=$os[1]; }
				}
				//--countries
				$dbcountries = explode(",",$result["countries"]);
				foreach ($dbcountries as $dbcountry) {
					$country=explode(":",$dbcountry);
					if ($dbcountry[0]!="") { $countries[$country[0]]=$country[1]; }
				}
			}
			//set new values
			//--browser
			if (!array_key_exists($wu->browser, $browsers)) { $browsers[$wu->browser]=1; }
			else { $browsers[$wu->browser]++; }
			//--os
			if (!array_key_exists($wu->os, $oss)) { $oss[$wu->os]=1; }
			else { $oss[$wu->os]++; }
			//--country
			if (!array_key_exists($wu->country, $countries)) { $countries[$wu->country]=1; }
			else { $countries[$wu->country]++; }

			//transform to string again to save in db
			//--browsers
			$newbrowsers = array();
			foreach ($browsers as $browser=>$quantity) { $newbrowsers[] = "$browser:$quantity"; }
			$newbrowsers = implode(",",$newbrowsers);
			//--oss
			$newoss = array();
			foreach ($oss as $os=>$quantity) { $newoss[] = "$os:$quantity"; }
			$newoss = implode(",",$newoss);
			//--countries
			$newcountries = array();
			foreach ($countries as $country=>$quantity) { $newcountries[] = "$country:$quantity"; }
			$newcountries = implode(",",$newcountries);

			//Monatsformat in der DB: 09/2009
			if ($now == $result["month"]) {
				$sql = "update site_visitors set `visits`=`visits`+1,`browsers`='$newbrowsers'".
				",`oss`='$newoss',`countries`='$newcountries' where `month`='$result[month]'";
			} else {
				$sql = "insert into site_visitors (`month`,`visits`,`browsers`,`oss`,`countries`) ".
				"values (DATE_FORMAT(now(),'%m/%Y'),1,'$newbrowsers','$newoss','$newcountries')";
			}
			db_query($sql);
		}
	}
}
} ?>
