--#################################################################################################
-- System Tables: Users, Groups, Installed Modules
--#################################################################################################

--Drop module tables if any------------------------------------------------------------------------
drop table if exists mod_guestbook;
drop table if exists mod_download;
drop table if exists mod_login;
--Drop all tables if they exist--------------------------------------------------------------------
drop table if exists site_visitors;
drop table if exists site_settings;
drop table if exists system_groups;
drop table if exists site_modules;
drop table if exists site_content;
drop table if exists system_modules;
drop table if exists system_users;
--Users--------------------------------------------------------------------------------------------
create table system_users (
`uid` int not null auto_increment,
`user` varchar(50) not null,
`name` varchar(50),
`pw` varchar(256) not null,
`email` varchar(100) not null,
`gids` text not null,
`active` bool not null default 0,
`lastlogin` datetime not null default '0000-00-00 00:00:00',
`logins` int not null default 0,
`language` varchar(20) not null default 'en',
`getnewsletter` bool not null default 1,
primary key (`uid`)
) engine = innodb character set latin1 collate latin1_general_ci;
-------------------------------------------------
insert into system_users (`uid`,`user`,`name`,`pw`,`email`,`gids`,`active`) values
(1,'admin','Administrator','26c669cd0814ac40e5328752b21c4aa6450d16295e4eec30356a06a911c23983aaebe12d5da38eeebfc1b213be650498df8419194d5a26c7e0a50af156853c79','admin@example.com','1',1);
--Groups-------------------------------------------------------------------------------------------
create table system_groups (
`gid` int not null auto_increment,
`name` varchar(50) not null default '',
`backend` bool not null default 0,
`write` bool not null default 0,
`moderator` int not null default 1,
primary key (`gid`),
CONSTRAINT systemgroups_moderator_systemusers_uid_fk FOREIGN KEY(`moderator`) REFERENCES system_users(`uid`)
) engine = innodb character set latin1 collate latin1_general_ci;
-------------------------------------------------
insert into system_groups (`gid`,`name`,`backend`,`write`) values
(1,'Admins',1,1),
(2,'Users',0,0);
--Modules installed in the CMS---------------------------------------------------------------------
create table system_modules (
`modid` int not null auto_increment,
`name` varchar(50) unique not null,
`author` varchar(50),
`version` varchar(10),
`type` tinyint not null,
`settings` text,
primary key (`modid`)
) engine = innodb  character set latin1 collate latin1_general_ci;
insert into system_modules (`modid`,`name`,`author`,`version`,`type`) values
(1,'content','FrozenPepper','2.1',0),
(2,'menu','FrozenPepper','2.0',1),
(3,'login','FrozenPepper','2.1',1);
--#################################################################################################
-- Pagespecific Tables: Settings, Active Modules, Content, Visitordata
--#################################################################################################
--Settings-----------------------------------------------------------------------------------------
create table site_settings (
`id` tinyint not null auto_increment,
`key` varchar(50) not null,
`value` text,
primary key (`id`)
) engine = innodb  character set latin1 collate latin1_general_ci;
insert into site_settings (`key`,`value`) values
('language','en'),
('sitename',null),
('author',null),
('siteemail',null),
('backendstyle','blue'),
('template','blue'),
('keywords',null),
('description',null),
('version','1.1.3'),
('adv_settings','0'),
('session_ltime','900'),
('mod_rewrite','0'),
('dbtype','mysql'),
('tbl_prefix',''),
('offline_mode','0'),
('offline_msg',null),
('allowed_ftypes','jpg,png,gif,zip,txt,doc,pdf,ppt,avi,mp3,tar.gz'),
('filesize_limit','2000000'),
('max_menudepth','2'),
('debug_mode','0');
--Active Modules-----------------------------------------------------------------------------------
create table site_modules (
`id` int not null auto_increment,
`name` varchar(50) not null,
`modid` int not null,
`position` varchar(20) not null default 'inactive',
`order` int not null default 0,
`active` bool not null default 1,
`access` tinyint not null default 0,
`specialaccess` varchar(100),
`settings` text,
primary key (`id`),
CONSTRAINT sitemodules_modid_systemmodules_modid_fk FOREIGN KEY(`modid`) REFERENCES system_modules(`modid`) on delete cascade
) engine = innodb  character set latin1 collate latin1_general_ci;
-------------------------------------------------
insert into site_modules (`name`,`modid`,`position`,`order`,`active`,`settings`) values
('Mainmenu',2,'left',1,1,'1,1,1,0');
--Content------------------------------------------------------------------------------------------
create table site_content (
`id` int not null auto_increment,
`name` varchar(50) not null,
`treeid` int not null default 1,
`depth` tinyint not null default 0,
`parentid` int not null default 0,
`order` int not null default 0,
`active` bool not null default 1,
`startpage` bool not null default 0,
`modid` int not null default 0,
`settings` text,
`access` tinyint not null default 0,
`specialaccess` varchar(100),
`uid` int not null default 1,
`date_new` datetime,
`date_edit` datetime,
`views` int not null default 0,
`content` longtext,
primary key (`id`),
CONSTRAINT sitecontent_uid_systemusers_uid_fk FOREIGN KEY(`uid`) REFERENCES system_users(`uid`),
CONSTRAINT sitecontent_modid_systemmodules_modid_fk FOREIGN KEY(`modid`) REFERENCES system_modules(`modid`) on delete cascade
) engine = innodb  character set latin1 collate latin1_general_ci;
-------------------------------------------------
insert into site_content (`id`,`name`,`treeid`,`depth`,`parentid`,`order`,`active`,`startpage`,`modid`,`date_new`,`date_edit`) values
(1,'Mainmenu',1,0,0,0,1,0,1,now(),now()),
	(2,'Home',1,1,1,1,1,1,1,now(),now());
--Site Visitors------------------------------------------------------------------------------------
create table site_visitors (
`id` int not null auto_increment,
`month` varchar (10) collate latin1_general_ci not null,
`visits` int not null default 0,
`browsers` text,
`oss` text,
`countries` text,
primary key (`id`)
) engine = innodb  character set latin1 collate latin1_general_ci;
-------------------------------------------------
insert into site_visitors (`month`) values
(DATE_FORMAT(now(),'%m/%Y'));
--#################################################################################################
-- Module Tables: Login(Feedback)
--#################################################################################################
--Mod Login----------------------------------------------------------------------------------------
create table mod_login (
`id` int not null auto_increment,
`uid` int not null,
`type` bool not null default 1,
`feedback` longtext not null,
primary key (`id`),
CONSTRAINT modlogin_uid_systemusers_uid_fk FOREIGN KEY(`uid`) REFERENCES system_users(`uid`)
) engine=innodb character set latin1 collate latin1_general_ci;
-------------------------------------------------
insert into mod_login (`uid`,`type`,`feedback`) values
(1,0,0);
